@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2018 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -9,9 +9,9 @@
 
 #include <asiolink/io_service.h>
 #include <cc/data.h>
-#include <dhcpsrv/daemon.h>
 #include <exceptions/exceptions.h>
 #include <log/logger_support.h>
+#include <process/daemon.h>
 #include <process/d_log.h>
 #include <process/d_process.h>
 #include <process/io_service_signal.h>
@@ -101,7 +101,7 @@ typedef boost::shared_ptr<DControllerBase> DControllerBasePtr;
 /// NOTE: Derivations must supply their own static singleton instance method(s)
 /// for creating and fetching the instance. The base class declares the instance
 /// member in order for it to be available for static callback functions.
-class DControllerBase : public dhcp::Daemon {
+class DControllerBase : public Daemon {
 public:
     /// @brief Constructor
     ///
@@ -114,7 +114,7 @@ public:
     virtual ~DControllerBase();
 
     /// @brief returns Kea version on stdout and exit.
-    /// redeclaration/redefinition. @ref isc::dhcp::Daemon::getVersion()
+    /// redeclaration/redefinition. @ref isc::process::Daemon::getVersion()
     std::string getVersion(bool extended);
 
     /// @brief Acts as the primary entry point into the controller execution
@@ -413,21 +413,6 @@ protected:
         return (io_service_);
     }
 
-    /// @brief Getter for fetching the name of the controller's config spec
-    /// file.
-    ///
-    /// @return returns the file name string.
-    const std::string getSpecFileName() const {
-        return (spec_file_name_);
-    }
-
-    /// @brief Setter for setting the name of the controller's config spec file.
-    ///
-    /// @param spec_file_name the file name string.
-    void setSpecFileName(const std::string& spec_file_name) {
-        spec_file_name_ = spec_file_name;
-    }
-
     /// @brief Static getter which returns the singleton instance.
     ///
     /// @return returns a pointer reference to the private singleton instance
@@ -614,9 +599,6 @@ private:
     /// is enabled (usually specified by the command line -t argument).
     bool check_only_;
 
-    /// @brief The absolute file name of the JSON spec file.
-    std::string spec_file_name_;
-
     /// @brief Pointer to the instance of the process.
     ///
     /// This is required for config and command handlers to gain access to
